# osais
The osais Python lib for connecting AIs to OSAIS cloud

## Install

pip install osais

## Requirements 

Kept minimal (boto3, Jinja2, requests, schedule, watchdog, Werkzeug)

AI that includes osais package must have a ./_input and a ./_output directory, for receiving and generating files
Support of uploading to AWS S3 is provided

## Support

eric [at] incubiq [dot] com
